## Arches Controlled Lists 1.0.0 Release Notes

Introducing Arches Controlled Lists, a new application designed to manage controlled lists and reference data within the Arches platform. This release provides the framework for creating, managing, and utilizing controlled lists in your Arches projects.

### Features

- Adds controlled lists and list item schema and APIs for managing controlled lists.
- Introduces Controlled List Manager UI for creating and managing controlled lists.
- Creates the "reference" data type for making reference to controlled list items in Arches resource data.
- Adds a new "reference_select" widget for working with the "reference" data type in forms and reports.